@@ -7,15 +7,6 @@ from django.core.validators import RegexValidator
 from django.utils import dateparse
 
 
-validate_path = RegexValidator(
-    re.compile(r"^[^\s:?#]+$", re.UNICODE),
-    message=(
-        "Enter a valid path without a URL scheme, query string, or fragment."
-    ),
-    code="invalid",
-)
-
-
 validate_parameter = RegexValidator(
     re.compile(r"^[-_\w=]+$", re.UNICODE),
     message="Enter a valid HTTP parameter name.",
@@ -23,6 +14,16 @@ validate_parameter = RegexValidator(
 )
 
 
+def validate_path_re(value):
+    try:
+        re.compile(value)
+    except re.error as e:
+        raise ValidationError(
+            "Enter either a valid path or a regular expression to match a "
+            "path, without a URL scheme, query string, or fragment."
+        ) from e
+
+
 def validate_boolean(value):
     message = "Enter one of 'on', 'off', 'true', 'false', etc."
     try:
